# -*- coding: utf-8 -*-
import med_data_science_helper.helper_acces_db as hadb
import med_data_science_helper.helper_integracion as hi
import med_data_science_helper.helper_siagie_kpi as hsk
import med_data_science_helper.helper_siagie_kpi_old as hsk_old
import med_data_science_helper.helper_terceros_kpi as htk

import med_data_science_helper.helper_constantes as hct

print(hct.MACRO_REGION)
